@@ -2,19 +2,20 @@
 /*  GMime
  *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 2.1
+ *  of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free
+ *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
+ *  02110-1301, USA.
  */
 
 
@@ -54,6 +55,18 @@
 
 #define _(x) x
 
+
+/**
+ * SECTION: gmime-gpg-context
+ * @title: GMimeGpgContext
+ * @short_description: GnuPG cipher contexts
+ * @see_also: #GMimeCipherContext
+ *
+ * A #GMimeGpgContext is a #GMimeCipherContext that uses GnuPG to do
+ * all of the encryption and digital signatures.
+ **/
+
+
 static void g_mime_gpg_context_class_init (GMimeGpgContextClass *klass);
 static void g_mime_gpg_context_init (GMimeGpgContext *ctx, GMimeGpgContextClass *klass);
 static void g_mime_gpg_context_finalize (GObject *object);
@@ -766,6 +779,8 @@ gpg_ctx_parse_status (struct _GpgCtx *gpg, GError **err)
 	
  parse:
 	
+	g_clear_error (err);
+	
 	inptr = gpg->statusbuf;
 	while (inptr < gpg->statusptr && *inptr != '\n')
 		inptr++;
@@ -876,6 +891,8 @@ gpg_ctx_parse_status (struct _GpgCtx *gpg, GError **err)
 		}
 		
 		if ((passwd = g_mime_session_request_passwd (gpg->session, prompt, TRUE, gpg->need_id, err))) {
+			g_free (prompt);
+			
 			if (!gpg->utf8) {
 				char *locale_passwd;
 				
@@ -891,17 +908,20 @@ gpg_ctx_parse_status (struct _GpgCtx *gpg, GError **err)
 			g_free (passwd);
 			
 			gpg->send_passwd = TRUE;
-		} else if (err && *err == NULL) {
-			g_set_error (err, GMIME_ERROR, ECANCELED, _("Canceled."));
+		} else {
+			if (err && *err == NULL)
+				g_set_error (err, GMIME_ERROR, ECANCELED, _("Canceled."));
+			
+			g_free (prompt);
+			
+			return -1;
 		}
-		
-		g_free (prompt);
 	} else if (!strncmp (status, "GOOD_PASSPHRASE", 15)) {
 		gpg->bad_passwds = 0;
 	} else if (!strncmp (status, "BAD_PASSPHRASE", 14)) {
 		gpg->bad_passwds++;
 		
-		g_mime_session_forget_passwd (gpg->session, gpg->userid, err);
+		g_mime_session_forget_passwd (gpg->session, gpg->userid, NULL);
 		
 		if (gpg->bad_passwds == 3) {
 			g_set_error (err, GMIME_ERROR, GMIME_ERROR_BAD_PASSWORD,
@@ -1830,7 +1850,7 @@ g_mime_gpg_context_new (GMimeSession *session, const char *path)
 	g_return_val_if_fail (GMIME_IS_SESSION (session), NULL);
 	g_return_val_if_fail (path != NULL, NULL);
 	
-	ctx = g_object_new (GMIME_TYPE_GPG_CONTEXT, NULL, NULL);
+	ctx = g_object_new (GMIME_TYPE_GPG_CONTEXT, NULL);
 	ctx->path = g_strdup (path);
 	
 	cipher = (GMimeCipherContext *) ctx;
