@@ -2,19 +2,20 @@
 /*  GMime
  *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 2.1
+ *  of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free
+ *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
+ *  02110-1301, USA.
  */
 
 
@@ -35,6 +36,17 @@
 
 #define d(x)
 
+
+/**
+ * SECTION: gmime-multipart
+ * @title: GMimeMultipart
+ * @short_description: MIME multiparts
+ * @see_also:
+ *
+ * A #GMimeMultipart represents all multipart/* MIME container parts.
+ **/
+
+
 /* GObject class methods */
 static void g_mime_multipart_class_init (GMimeMultipartClass *klass);
 static void g_mime_multipart_init (GMimeMultipart *multipart, GMimeMultipartClass *klass);
@@ -231,8 +243,11 @@ multipart_write_to_stream (GMimeObject *object, GMimeStream *stream)
 	GMimeObject *part;
 	GList *node;
 	
-	/* make sure a boundary is set */
-	if (!multipart->boundary)
+	/* make sure a boundary is set unless we are writing out a raw
+	 * header (in which case it should already be set... or if
+	 * not, then it's a broken multipart/* and so we don't want to
+	 * alter it or we'll completely break the output) */
+	if (!multipart->boundary && !g_mime_header_has_raw (object->headers))
 		g_mime_multipart_set_boundary (multipart, NULL);
 	
 	/* write the content headers */
@@ -274,10 +289,13 @@ multipart_write_to_stream (GMimeObject *object, GMimeStream *stream)
 		node = node->next;
 	}
 	
-	if ((nwritten = g_mime_stream_printf (stream, "\n--%s--\n", multipart->boundary)) == -1)
-		return -1;
-	
-	total += nwritten;
+	/* write the end-boundary (but only if a boundary is set) */
+	if (multipart->boundary) {
+		if ((nwritten = g_mime_stream_printf (stream, "\n--%s--\n", multipart->boundary)) == -1)
+			return -1;
+		
+		total += nwritten;
+	}
 	
 	/* write the postface */
 	if (multipart->postface) {
@@ -301,7 +319,7 @@ multipart_write_to_stream (GMimeObject *object, GMimeStream *stream)
  * multipart/mixed.
  **/
 GMimeMultipart *
-g_mime_multipart_new ()
+g_mime_multipart_new (void)
 {
 	GMimeMultipart *multipart;
 	GMimeContentType *type;
