@@ -43,6 +43,17 @@
 #define d(x)
 
 
+/**
+ * SECTION: internet-address
+ * @title: InternetAddress
+ * @short_description: Internet addresses
+ * @see_also:
+ *
+ * An #InternetAddress represents what is commonly referred to as an
+ * E-Mail address.
+ **/
+
+
 /**
  * internet_address_new:
  *
@@ -251,7 +262,10 @@ internet_address_add_member (InternetAddress *ia, InternetAddress *member)
  * internet_address_get_type:
  * @ia: internet address
  *
- * Returns the type of the internet address.
+ * Gets the type of the internet address, which will either be
+ * #INTERNET_ADDRESS_NAME or #INTERNET_ADDRESS_GROUP.
+ *
+ * Returns the type of @ia.
  **/
 InternetAddressType
 internet_address_get_type (InternetAddress *ia)
@@ -265,7 +279,10 @@ internet_address_get_type (InternetAddress *ia)
  * internet_address_get_name:
  * @ia: internet address
  *
- * Returns the name of the internet address.
+ * Gets the name component of the internet address. If the internet
+ * address is a group, it will get the group name.
+ *
+ * Returns the name of @ia.
  **/
 const char *
 internet_address_get_name (InternetAddress *ia)
@@ -280,7 +297,9 @@ internet_address_get_name (InternetAddress *ia)
  * internet_address_get_addr:
  * @ia: internet address
  *
- * Returns the address of the internet address.
+ * Gets the addr-spec of the internet address.
+ *
+ * Returns the address of @ia.
  **/
 const char *
 internet_address_get_addr (InternetAddress *ia)
@@ -296,7 +315,10 @@ internet_address_get_addr (InternetAddress *ia)
  * internet_address_get_members:
  * @ia: internet address
  *
- * Returns the list of internet addresses.
+ * Gets the #InternetAddressList containing the group members of an
+ * rfc822 group address.
+ *
+ * Returns the members of @ia.
  **/
 const InternetAddressList *
 internet_address_get_members (InternetAddress *ia)
@@ -313,7 +335,7 @@ internet_address_get_members (InternetAddress *ia)
  * @list: a list of internet addresses
  * @ia: internet address to prepend
  *
- * Prepends the internet address to the list of internet addresses
+ * Prepends the internet address @ia to the list of internet addresses
  * pointed to by @list.
  *
  * Returns the resultant list.
@@ -327,8 +349,8 @@ internet_address_list_prepend (InternetAddressList *list, InternetAddress *ia)
 	
 	internet_address_ref (ia);
 	node = g_new (InternetAddressList, 1);
-	node->next = list;
 	node->address = ia;
+	node->next = list;
 	
 	return node;
 }
@@ -771,8 +793,7 @@ decode_mailbox (const char **in)
 			g_string_append (name, pre);
 			g_free (pre);
 		retry:
-			pre = decode_word (&inptr);
-			if (pre)
+			if ((pre = decode_word (&inptr)))
 				g_string_append_c (name, ' ');
 		}
 		
@@ -782,7 +803,7 @@ decode_mailbox (const char **in)
 			bracket = TRUE;
 			pre = decode_word (&inptr);
 		} else if (!retried && *inptr) {
-			w(g_warning ("Unexpected char '%c' in address: %s: attempting recovery.",
+			w(g_warning ("Unexpected char '%c' in mailbox: %s: attempting recovery.",
 				     *inptr, *in));
 			/* chew up this bad char and then attempt 1 more pass at parsing */
 			g_string_append_c (name, *inptr++);
@@ -885,21 +906,12 @@ decode_mailbox (const char **in)
 	
 	if (addr->len) {
 		if (name && !g_utf8_validate (name->str, -1, NULL)) {
-			/* A (broken) mailer has sent us an unencoded
-			 * 8bit value (and it doesn't seem to be valid
-			 * UTF-8 either).  Attempt to save it by
-			 * assuming it's in the user's locale and
-			 * converting to UTF-8 */
-			char *buf;
+			/* A (broken) mailer has sent us raw 8bit/multibyte text data... */
+			char *utf8 = g_mime_utils_decode_8bit (name->str, name->len);
 			
-			if ((buf = g_mime_iconv_locale_to_utf8 (name->str))) {
-				g_string_truncate (name, 0);
-				g_string_append (name, buf);
-				g_free (buf);
-			} else {
-				d(g_warning ("Failed to convert \"%s\" to UTF-8: %s",
-					     name->str, g_strerror (errno)));
-			}
+			g_string_truncate (name, 0);
+			g_string_append (name, utf8);
+			g_free (utf8);
 		}
 		
 		mailbox = internet_address_new_name (name ? name->str : NULL, addr->str);
@@ -930,8 +942,7 @@ decode_address (const char **in)
 		g_string_append (name, pre);
 		g_free (pre);
 		
-		pre = decode_word (&inptr);
-		if (pre)
+		if ((pre = decode_word (&inptr)))
 			g_string_append_c (name, ' ');
 	}
 	
